#[repr(transparent)]pub struct EditableAvatar {
inner: TypedObjectRef<EditableAvatar, <EditableAvatar as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
An Avatar that can be edited.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<EditableAvatar, <EditableAvatar as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl EditableAvatar
impl EditableAvatar
Sourcepub fn data(&self) -> <BoundObject<AvatarData> as Property>::Value
pub fn data(&self) -> <BoundObject<AvatarData> as Property>::Value
The AvatarData to display.
Sourcepub fn set_data<'a>(
&self,
value: impl Borrow<<<BoundObject<AvatarData> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_data<'a>( &self, value: impl Borrow<<<BoundObject<AvatarData> as Property>::Value as HasParamSpec>::SetValue>, )
The AvatarData to display.
Sourcepub fn image(&self) -> <BoundObjectWeakRef<AvatarImage> as Property>::Value
pub fn image(&self) -> <BoundObjectWeakRef<AvatarImage> as Property>::Value
The avatar image to watch.
Sourcepub fn set_editable<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_editable<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this avatar is changeable.
Sourcepub fn inhibit_remove(&self) -> <Cell<bool> as Property>::Value
pub fn inhibit_remove(&self) -> <Cell<bool> as Property>::Value
Whether to prevent the remove button from showing.
Sourcepub fn set_inhibit_remove<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_inhibit_remove<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether to prevent the remove button from showing.
Sourcepub fn state(&self) -> <Cell<EditableAvatarState> as Property>::Value
pub fn state(&self) -> <Cell<EditableAvatarState> as Property>::Value
The current state of the edit.
Sourcepub fn set_state<'a>(
&self,
value: impl Borrow<<<Cell<EditableAvatarState> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_state<'a>( &self, value: impl Borrow<<<Cell<EditableAvatarState> as Property>::Value as HasParamSpec>::SetValue>, )
The current state of the edit.
Sourcepub fn temp_paintable(&self) -> <RefCell<Option<Paintable>> as Property>::Value
pub fn temp_paintable(&self) -> <RefCell<Option<Paintable>> as Property>::Value
A temporary paintable to show instead of the avatar.
Sourcepub fn connect_data_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_data_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the data property
Sourcepub fn connect_image_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_image_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the image property
Sourcepub fn connect_editable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_editable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the editable property
Sourcepub fn connect_inhibit_remove_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_inhibit_remove_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the inhibit-remove property
Sourcepub fn connect_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the state property
Sourcepub fn connect_temp_paintable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_temp_paintable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the temp-paintable property
Sourcepub fn notify_data(&self)
pub fn notify_data(&self)
Notify listeners of a change in the data property
Sourcepub fn notify_image(&self)
pub fn notify_image(&self)
Notify listeners of a change in the image property
Sourcepub fn notify_editable(&self)
pub fn notify_editable(&self)
Notify listeners of a change in the editable property
Sourcepub fn notify_inhibit_remove(&self)
pub fn notify_inhibit_remove(&self)
Notify listeners of a change in the inhibit-remove property
Sourcepub fn notify_state(&self)
pub fn notify_state(&self)
Notify listeners of a change in the state property
Sourcepub fn notify_temp_paintable(&self)
pub fn notify_temp_paintable(&self)
Notify listeners of a change in the temp-paintable property
Sourceimpl EditableAvatar
impl EditableAvatar
pub fn new() -> Self
Sourcepub(crate) fn edit_in_progress(&self)
pub(crate) fn edit_in_progress(&self)
Show that an edit is in progress.
Sourcepub(crate) fn removal_in_progress(&self)
pub(crate) fn removal_in_progress(&self)
Show that a removal is in progress.
Sourcepub(crate) fn success(&self)
pub(crate) fn success(&self)
Show that the current ongoing action was successful.
This is has no effect if no action is ongoing.
Sourcepub(super) async fn choose_avatar(&self)
pub(super) async fn choose_avatar(&self)
Choose a new avatar.
Sourcepub fn connect_edit_avatar<F: Fn(&Self, File) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_edit_avatar<F: Fn(&Self, File) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when a new avatar is selected.
Sourcepub fn connect_remove_avatar<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_remove_avatar<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the avatar is removed.